@@ -27,11 +27,12 @@ test_get_adi_arg_tibble <- function(geography,
       county, 
       zcta, 
       geography, 
+      year,
       dataset,
       exec_arg_tibble
     )
   
-  tidyr::crossing(exec_arg_tibble, ref_area$state_county)
+  cross_args(exec_arg_tibble, ref_area$state_county, geography, year, dataset)
 }
 
 
@@ -43,7 +44,11 @@ vars2010 <-
   sociome::decennial_vars %>% 
   dplyr::filter(.data$year == 2010) %>%
   dplyr::pull("variable") %>% 
-  list(sociome::acs_vars %>% dplyr::filter(.data$decennial2010) %>% dplyr::pull("variable"))
+  list(
+    sociome::acs_vars %>%
+      dplyr::filter(.data$dec2010) %>%
+      dplyr::pull("variable")
+  )
 
 
 test_that("call tibble for geoids is correct", {
@@ -60,13 +65,13 @@ test_that("call tibble for geoids is correct", {
     ),
     tibble::tibble(
       .fn = list(tidycensus::get_decennial, tidycensus::get_acs),
+      geography = "state",
       variables = vars2010,
       sumfile = list("sf1", NULL),
       year = 2010,
       output = "tidy",
       keep_geo_vars = FALSE,
       endyear = list(NULL),
-      geography = list("state"),
       geometry = list(FALSE),
       shift_geo = list(FALSE),
       cache_table = list(FALSE),
@@ -87,13 +92,13 @@ test_that("call tibble for geoids is correct", {
     ),
     tibble::tibble(
       .fn = list(tidycensus::get_decennial, tidycensus::get_acs),
+      geography = "county",
       variables = vars2010,
       sumfile = list("sf1", NULL),
       year = 2010,
       output = "tidy",
       keep_geo_vars = FALSE,
       endyear = list(NULL),
-      geography = list("county"),
       geometry = list(FALSE),
       shift_geo = list(FALSE),
       cache_table = list(FALSE),
@@ -102,6 +107,12 @@ test_that("call tibble for geoids is correct", {
     )
   )
   
+  
+  
+  skip_if(Sys.getenv("CENSUS_API_KEY") == "")
+  
+  
+  
   expect_identical(
     test_get_adi_arg_tibble(
       geography = "tract",
@@ -113,28 +124,31 @@ test_that("call tibble for geoids is correct", {
       zcta = NULL
     ),
     tibble::tibble(
-      .fn = c(rep(list(tidycensus::get_decennial), 4L), rep(list(tidycensus::get_acs), 4L)),
-      variables = purrr::lmap(vars2010, rep, 4L),
-      sumfile = c(rep("sf1", 4L), rep(list(NULL), 4L)),
+      .fn = c(rep(list(tidycensus::get_decennial), 4L), rep(list(tidycensus::get_acs), 72)),
+      geography = "tract",
+      variables = c(rep(vars2010[1L], 4L), rep(vars2010[2L], 72)),
+      sumfile = c(rep("sf1", 4L), rep(list(NULL), 72L)),
       year = 2010,
       output = "tidy",
       keep_geo_vars = FALSE,
       endyear = list(NULL),
-      geography = list("tract"),
       geometry = list(FALSE),
       shift_geo = list(FALSE),
       cache_table = list(FALSE),
       key = list(NULL),
-      state = c("01", "09" , "11", "39", "01", "09" , "11", "39")
+      state = c("39", "09", "01", "11",
+                "39", "39", "09", "09", rep("01", 67L), "11"),
+      county =
+        c(rep(list(NULL), 4L),
+          "035", "089",
+          "001", "015",
+          "001", "007", "017", "019", "025", "013", "009", "011", "021", "023", "037", "027", "029", "031", "035", "033", "053", "039", "041", "043", "045", "047", "049", "051", "065", "055", "057", "059", "061", "063", "081", "067", "069", "071", "073", "075", "077", "079", "099", "083", "085", "087", "089", "091", "093", "097", "095", "115", "101", "103", "105", "107", "109", "111", "113", "127", "117", "119", "121", "123", "125", "129", "131", "133", "003", "005", "015",
+          "001")
     )
   )
   
   
   
-  skip_if(Sys.getenv("CENSUS_API_KEY") == "")
-  
-  
-  
   expect_identical(
     test_get_adi_arg_tibble(
       geography = "block group",
@@ -148,13 +162,13 @@ test_that("call tibble for geoids is correct", {
       dplyr::arrange(.data$state, .data$county),
     tibble::tibble(
       .fn = c(rep(list(tidycensus::get_decennial), 72L), rep(list(tidycensus::get_acs), 72L)),
+      geography = "block group",
       variables = purrr::lmap(vars2010, rep, 72),
       sumfile = c(rep("sf1", 72L), rep(list(NULL), 72L)),
       year = 2010,
       output = "tidy",
       keep_geo_vars = FALSE,
       endyear = list(NULL),
-      geography = list("block group"),
       geometry = list(FALSE),
       shift_geo = list(FALSE),
       cache_table = list(FALSE),
@@ -199,13 +213,13 @@ test_that("call tibble for state only is correct", {
     ),
     tibble::tibble(
       .fn = list(tidycensus::get_decennial, tidycensus::get_acs),
+      geography = "state",
       variables = vars2010,
       sumfile = list("sf1", NULL),
       year = 2010,
       output = "tidy",
       keep_geo_vars = FALSE,
       endyear = list(NULL),
-      geography = list("state"),
       geometry = list(FALSE),
       shift_geo = list(FALSE),
       cache_table = list(FALSE),
@@ -227,13 +241,13 @@ test_that("call tibble for state only is correct", {
     ),
     tibble::tibble(
       .fn = list(tidycensus::get_decennial, tidycensus::get_acs),
+      geography = "county",
       variables = vars2010,
       sumfile = list("sf1", NULL),
       year = 2010,
       output = "tidy",
       keep_geo_vars = FALSE,
       endyear = list(NULL),
-      geography = list("county"),
       geometry = list(FALSE),
       shift_geo = list(FALSE),
       cache_table = list(FALSE),
@@ -243,6 +257,12 @@ test_that("call tibble for state only is correct", {
     )
   )
 
+  
+  
+  skip_if(Sys.getenv("CENSUS_API_KEY") == "")
+  
+  
+  
   expect_identical(
     test_get_adi_arg_tibble(
       geography = "tract",
@@ -254,27 +274,30 @@ test_that("call tibble for state only is correct", {
       zcta = NULL
     ),
     tibble::tibble(
-      .fn = c(rep(list(tidycensus::get_decennial), 3L), rep(list(tidycensus::get_acs), 3L)),
-      variables = purrr::lmap(vars2010, rep, 3L),
-      sumfile = c(rep("sf1", 3L), rep(list(NULL), 3L)),
+      .fn = c(rep(list(tidycensus::get_decennial), 3L),
+              rep(list(tidycensus::get_acs), 12)),
+      geography = "tract",
+      variables = c(rep(vars2010[1L], 3L), rep(vars2010[2L], 12L)),
+      sumfile = c(rep("sf1", 3L), rep(list(NULL), 12L)),
       year = 2010,
       output = "tidy",
       keep_geo_vars = FALSE,
       endyear = list(NULL),
-      geography = list("tract"),
       geometry = list(FALSE),
       shift_geo = list(FALSE),
       cache_table = list(FALSE),
       key = list(NULL),
-      state = c("ct", "dc", "de", "ct", "dc", "de")
+      state = 
+        c("09", "10", "11",
+          "09", "09", "09", "09", "09", "09", "09", "09", "10", "10", "10", "11"),
+      county = 
+        c(rep(list(NULL), 3L),
+          "001", "005", "003", "007", "015", "009", "011", "013", "001", "005", "003", "001")
     )
   )
   
   
   
-  skip_if(Sys.getenv("CENSUS_API_KEY") == "")
-
-
   expect_identical(
     test_get_adi_arg_tibble(
       geography = "block group",
@@ -287,13 +310,13 @@ test_that("call tibble for state only is correct", {
     ) %>% dplyr::arrange(.data$state, .data$county),
     tibble::tibble(
       .fn = c(rep(list(tidycensus::get_decennial), 12L), rep(list(tidycensus::get_acs), 12L)),
+      geography = "block group",
       variables = purrr::lmap(vars2010, rep, 12L),
       sumfile = c(rep("sf1", 12L), rep(list(NULL), 12L)),
       year = 2010,
       output = "tidy",
       keep_geo_vars = FALSE,
       endyear = list(NULL),
-      geography = list("block group"),
       geometry = list(FALSE),
       shift_geo = list(FALSE),
       cache_table = list(FALSE),
@@ -331,13 +354,13 @@ test_that("call tibble for one state and multiple counties is correct", {
     ),
     tibble::tibble(
       .fn = list(tidycensus::get_decennial, tidycensus::get_acs),
+      geography = "state",
       variables = vars2010,
       sumfile = list("sf1", NULL),
       year = 2010,
       output = "tidy",
       keep_geo_vars = FALSE,
       endyear = list(NULL),
-      geography = list("state"),
       geometry = list(FALSE),
       shift_geo = list(FALSE),
       cache_table = list(FALSE),
@@ -359,13 +382,13 @@ test_that("call tibble for one state and multiple counties is correct", {
     ),
     tibble::tibble(
       .fn = list(tidycensus::get_decennial, tidycensus::get_acs),
+      geography = "county",
       variables = vars2010,
       sumfile = list("sf1", NULL),
       year = 2010,
       output = "tidy",
       keep_geo_vars = FALSE,
       endyear = list(NULL),
-      geography = list("county"),
       geometry = list(FALSE),
       shift_geo = list(FALSE),
       cache_table = list(FALSE),
@@ -386,22 +409,20 @@ test_that("call tibble for one state and multiple counties is correct", {
       zcta = NULL
     ),
     tibble::tibble(
-      .fn = c(rep(list(tidycensus::get_decennial), 4L), rep(list(tidycensus::get_acs), 4L)),
-      variables = purrr::lmap(vars2010, rep, 4L),
-      sumfile = c(rep("sf1", 4L), rep(list(NULL), 4L)),
+      .fn = c(tidycensus::get_decennial, rep(list(tidycensus::get_acs), 4L)),
+      geography = "tract",
+      variables = c(vars2010[1L], rep(vars2010[2L], 4L)),
+      sumfile = c("sf1", rep(list(NULL), 4L)),
       year = 2010,
       output = "tidy",
       keep_geo_vars = FALSE,
       endyear = list(NULL),
-      geography = list("tract"),
       geometry = list(FALSE),
       shift_geo = list(FALSE),
       cache_table = list(FALSE),
       key = list(NULL),
-      state = rep("oh", 8L),
-      county =
-        c("cuyahoga", "erie", "franklin", "lake",
-          "cuyahoga", "erie", "franklin", "lake")
+      state = rep("oh", 5L),
+      county = list(NULL, "cuyahoga", "erie", "franklin", "lake")
     )
   )
 
@@ -418,13 +439,13 @@ test_that("call tibble for one state and multiple counties is correct", {
     ),
     tibble::tibble(
       .fn = c(rep(list(tidycensus::get_decennial), 4L), rep(list(tidycensus::get_acs), 4L)),
+      geography = "block group",
       variables = purrr::lmap(vars2010, rep, 4L),
       sumfile = c(rep("sf1", 4L), rep(list(NULL), 4L)),
       year = 2010,
       output = "tidy",
       keep_geo_vars = FALSE,
       endyear = list(NULL),
-      geography = list("block group"),
       geometry = list(FALSE),
       shift_geo = list(FALSE),
       cache_table = list(FALSE),
